@@ -267,7 +267,7 @@ void segatex::segatex_show_interface()
 	using namespace std;
 	using namespace boost;
 	const char* filename="/var/log/audit/audit.log";
-        const char* filename_new="./segatex_audit_denied.log";
+        ////const char* filename_new="./segatex_audit_denied.log";
         const char* filename_policy="./my_policy_by_segatex.te";
 	if(log_state == 0){
 		log_from_time_int = segatex::segatex_set_time_all_real(); 
@@ -303,16 +303,24 @@ void segatex::segatex_show_interface()
 		}
 		if(is)
 		{
+/*added 2 lines*/
+			vector<string> v;
+			vector<string>::iterator p, p_end;
+
 			vector<string> v2;
 			vector<string>::iterator p2_v, p2_v_end;
 			multimap<string ,string>::iterator p2,p2_end;
 			multimap<string ,string>::iterator p2_m,p2_m_end;
+/*
 			ofstream os;
 			os.open(filename_new);
+*/
 			ofstream os_policy;
 			os_policy.open(filename_policy);
-			if((os_policy)&&(os))
+			////if((os_policy)&&(os))
+			if(os_policy)
 			{
+/*
 				char buffer[MAX_LOG];
 				const char* words="denied";
 				vector<string> v;
@@ -327,6 +335,15 @@ void segatex::segatex_show_interface()
 					break;
 				}
 				os.close();
+*/
+				char buffer[MAX_LOG];
+				const char* words="denied";
+				while(is.getline(buffer, sizeof buffer))
+				{
+					if(strstr(buffer,words)){
+						v.push_back(buffer);
+					}
+				}
 	//FC5Υη
 	//type=AVC msg=audit(1152547592.021:9): avc:  denied  { tcp_send } for  pid=1638 comm="httpd" saddr=0000:0000:0000:0000:0000:0000:0000:0001 src=42207 daddr=0000:0000:0000:0000:0000:0000:0000:0001 dest=443 netif=lo scontext=system_u:system_r:httpd_t:s0 tcontext=system_u:object_r:compat_ipv4_node_t:s0 tclass=node
 
@@ -584,7 +601,7 @@ void segatex::segatex_show_interface()
 					if(regex_search(source_m,what,m_interface_pre_exp)){
 						source_interface_pre  = what[0];
 						/*for debug*/
-				//		os_policy << source_interface_pre << endl;	
+						//os_policy << source_interface_pre << endl;	
 						/*end for debug*/
 						//ok,ǡhttpd_t:file Ǥ
 						if(source_interface_pre != source_interface_pre_prev){
@@ -686,23 +703,27 @@ void segatex::segatex_show_interface()
 										//ǡhttpd_t:file multimap餵ơdomainѴmatchedΥ٥ѤȤǤꡣ
 										//Ȥä顢interfaceϤäȹΤǡinterfaceȤ٥Ѥǡ⤦󥨥󥸥ˤobjectclass,access_vectorФɬפä
 										int length=strlen(result.str().c_str());
-										string blank_str="";
-										string interface_raw_str=result.str().replace(length -1,1,blank_str);
-										v_interface_raw.push_back(interface_raw_str.c_str());
-										//os_policy << interface_raw_str << endl;
-										p_pattern_not_matched_domain=pattern_not_matched_domain.find(source_interface_pre);
-										if(p_pattern_not_matched_domain != pattern_not_matched_domain.end()){
-											do{
-												int length=strlen(result.str().c_str());
-												string blank_str="";
-												string result_str=result.str().replace(length -1,1,blank_str);
-												
-												//string domain_interface_echo = result.str() + bracket_first_str + p_pattern_not_matched_domain->second + bracket_last_str;  
-												string domain_interface_echo = result_str + bracket_first_str + p_pattern_not_matched_domain->second + bracket_last_str;  
-												v_domain_interface.push_back(domain_interface_echo.c_str());
-												//os_policy << result.str() << "(" << p_pattern_not_matched_domain->second << ")" << endl;
-												p_pattern_not_matched_domain++;
-											}while(p_pattern_not_matched_domain != pattern_not_matched_domain.upper_bound(source_interface_pre));
+										//2.03ɮʬʶԤΤɤ
+										if(length >1){
+											string blank_str="";
+											string interface_raw_str=result.str().replace(length -1,1,blank_str);
+											v_interface_raw.push_back(interface_raw_str.c_str());
+											//os_policy << interface_raw_str << endl;
+											p_pattern_not_matched_domain=pattern_not_matched_domain.find(source_interface_pre);
+											if(p_pattern_not_matched_domain != pattern_not_matched_domain.end()){
+												do{
+													int length=strlen(result.str().c_str());
+													string blank_str="";
+													string result_str=result.str().replace(length -1,1,blank_str);
+													
+													//string domain_interface_echo = result.str() + bracket_first_str + p_pattern_not_matched_domain->second + bracket_last_str;  
+													string domain_interface_echo = result_str + bracket_first_str + p_pattern_not_matched_domain->second + bracket_last_str;  
+													//ǥ󥿥ե(ɥᥤ)ѤǤ
+													v_domain_interface.push_back(domain_interface_echo.c_str());
+													//os_policy << result.str() << "(" << p_pattern_not_matched_domain->second << ")" << endl;
+													p_pattern_not_matched_domain++;
+												}while(p_pattern_not_matched_domain != pattern_not_matched_domain.upper_bound(source_interface_pre));
+											}
 										}
 										//pattern_matched_tclassobjclass_interface.insert(pair<string, string>(source_interface_pre,result.str()));
 									}
@@ -743,7 +764,7 @@ void segatex::segatex_show_interface()
 						}
 						source_interface_pre_comp = source_interface_pre;
 					}
-					/*ޥåʤäȤεߺѺǡallowʸФ*/
+					//ޥåʤäȤεߺѺǡallowʸФ٤ν
 					//os_policy << source_interface_pre ;
 					//os_policy << " was_not_matched !!!!!!!!"<< endl;
 					/*ޥåʤäۤϡǤޤȤơ٥ƥʤѤǤ夫饽ȥˡƽФ*/	
@@ -775,26 +796,31 @@ void segatex::segatex_show_interface()
 				}
 				/*end read the engine agin and check...*/
 				/*2ܤθꤳܤʬȤ󥿥եäƤ*/
+				/*ϵդʤȡФƤ뤫狼ʤޤ󥸥󤬤ܤȤäƤޤФޤǤ*/
 				for(p_interface_raw=v_interface_raw.begin(); p_interface_raw < v_interface_raw.end(); p_interface_raw++){
 					//ʸϡsource_interface_raw ʤ㡧userdom_manage_generic_user_home_content_files
 					string source_interface_raw = *p_interface_raw;
 					const char* m_source_interface_raw = source_interface_raw.c_str();
-					const char* m_domain_interface_h = "[a-z0-9_]*_t:";
-					const char* m_objclass_interface_h = ":(.*)\\{";
+					const char* m_domain_interface_h = "[a-z][a-z0-9_]*_t:";
+					const char* m_objclass_interface_h = ":.*?\\{";
+					const char* m_objclass_interface_h_dash = ":[a-z0-9_]*";
 					const char* m_objclass_interface_h2 = ":(.*)([^[:space:]*])[[:space:]]";
+					//ǡ{{}}ȤΤȤʤ褦ˤʤ̵äݤΤǡǤ뤫
 					const char* m_accv_interface_h = "\\{(.*)\\}";
 					const char* m_accv_interface_h2 = "[[:space:]][a-z0-9_]*;,";
 					string blank_str="";
 					string space_str=" ";
+					string tiruda_str="~";
 					regex m_source_interface_raw_exp(m_source_interface_raw);
 					regex m_domain_interface_h_exp(m_domain_interface_h);
 					regex m_objclass_interface_h_exp(m_objclass_interface_h);
+					regex m_objclass_interface_h_dash_exp(m_objclass_interface_h_dash);
 					regex m_objclass_interface_h2_exp(m_objclass_interface_h2);
 					regex m_accv_interface_h_exp(m_accv_interface_h);
 					regex m_accv_interface_h2_exp(m_accv_interface_h2);
-					/*read the engine and check*/
-					/*󥸥ե夫鸡롣forפСޥåƤ*/
-					/*⤦󡢼ꤳܤobjectclass򸡺*/
+					//read the engine and check
+					//󥸥ե夫鸡롣forפСޥåƤ
+					//⤦󡢼ꤳܤobjectclass򸡺
 					string domain_interface_h;
 					string objclass_interface_h;
 					string objclass_interface_h2;
@@ -819,31 +845,35 @@ void segatex::segatex_show_interface()
 							}
 							if(regex_search(source_engine_str,what,m_objclass_interface_h_exp)){
 								objclass_interface_h = what[0];
+								const char* objclass_interface_h_cstr=objclass_interface_h.c_str();
+								if(regex_search(objclass_interface_h_cstr,what,m_objclass_interface_h_dash_exp)){
+									objclass_interface_h = what[0];
+								}
 								objclass_interface_h=objclass_interface_h.replace(0,1,blank_str);
-								int length=strlen(objclass_interface_h.c_str());
-								objclass_interface_h=objclass_interface_h.replace(length-2,2,blank_str);
-								//os_policy << "objclass_interface_h:" << objclass_interface_h <<endl;
+								//os_policy << "objclass_interface_h" << objclass_interface_h << ":" << endl;
 								//v_tmp_objclassϡ¤ϸΥȤʤΤǡ֤줿(󥿥եäƤ)
 								//objclassѤǤʤȥᡣ
 								//Ǥϡv_matched_tmp_objclassѤߡȤv_tmp_objclass˲ä
 								v_matched_tmp_objclass.push_back(objclass_interface_h.c_str());
 								objclass_interface_h = objclass_interface_h + space_str ;
-								//os_policy << objclass_interface_h << endl;	
-							}
-							/*С2.02ɮʬʥ٥{}ǰϤޤƤ櫓Ǥ̵*/
-							if(regex_search(source_engine_str,what,m_objclass_interface_h2_exp)){
-								objclass_interface_h2 = what[0];
-								objclass_interface_h2=objclass_interface_h2.replace(0,1,blank_str);
-								int length=strlen(objclass_interface_h2.c_str());
-								objclass_interface_h2=objclass_interface_h2.replace(length-1,1,blank_str);
-								//os_policy << "objclass_interface_h2:" << objclass_interface_h2 <<endl;
-								//v_tmp_objclassϡ¤ϸΥȤʤΤǡ֤줿(󥿥եäƤ)
-								//objclassѤǤʤȥᡣ
-								//Ǥϡv_matched_tmp_objclassѤߡȤv_tmp_objclass˲ä
-								v_matched_tmp_objclass.push_back(objclass_interface_h2.c_str());
-								objclass_interface_h2 = objclass_interface_h2 + space_str ;
+							}else{
+								//С2.03ɮʬʡelseˤƤʤäΤǡѤʻˤʤäƤ...
+								//С2.02ɮʬʥ٥{}ǰϤޤƤ櫓Ǥ̵
+								if(regex_search(source_engine_str,what,m_objclass_interface_h2_exp)){
+									objclass_interface_h2 = what[0];
+									objclass_interface_h2=objclass_interface_h2.replace(0,1,blank_str);
+									int length=strlen(objclass_interface_h2.c_str());
+									objclass_interface_h2=objclass_interface_h2.replace(length-1,1,blank_str);
+									//os_policy << "objclasss_interface_h2" << objclass_interface_h2 << ":" << endl;	
+									//v_tmp_objclassϡ¤ϸΥȤʤΤǡ֤줿(󥿥եäƤ)
+									//objclassѤǤʤȥᡣ
+									//Ǥϡv_matched_tmp_objclassѤߡȤv_tmp_objclass˲ä
+									v_matched_tmp_objclass.push_back(objclass_interface_h2.c_str());
+									objclass_interface_h2 = objclass_interface_h2 + space_str ;
+								}
 							}
 							if(regex_search(source_engine_str,what,m_accv_interface_h_exp)){
+								//
 								accv_interface_h = what[0];
 								string bracket_first_str="{";
 								string bracket_last_str="{";
@@ -852,32 +882,42 @@ void segatex::segatex_show_interface()
 								accv_interface_h=accv_interface_h.replace(length -1,1,blank_str);
 								//os_policy << accv_interface_h << endl;	
 								regex tmp_re("[[:space:]]([^[:space:]]*)[a-z0-9_]*");
+								regex tmp_re2("[[:space:]][a-z0-9_]*_t");
 								string::const_iterator it=accv_interface_h.begin(), end=accv_interface_h.end();
-								while(it != end){
+								while(it != end-1){
 									smatch result;
 									if( !regex_search(it, end, result, tmp_re)){
 										break;
 									}
-									pattern_matched_access_vector.insert(pair<string, string>(objclass_interface_h,result.str()));
-									//os_policy << "interface<" <<objclass_interface_h << ":" << result.str() << ">" << endl;
-									//os_policy << "interfaceäƤobjclass:" << objclass_interface_h << "; <<<< endl;
+									if((result.str() != " {")&&(result.str() != " }")){
+										const char* result_str_cstr = result.str().c_str();
+										if(regex_search(result_str_cstr,what,tmp_re2)){
+											//ѤʤΤѤޤʤ
+										}else{
+											pattern_matched_access_vector.insert(pair<string, string>(objclass_interface_h,result.str()));
+											//os_policy << "interface<" <<objclass_interface_h << ":" << result.str() << ">" << endl;
+										}
+									}
+
+									//os_policy << "interfaceäƤobjclass:" << objclass_interface_h << ";"<< endl;
 									v_matched_tmp_objclass.push_back(objclass_interface_h.c_str());
 									it = result[0].second;
 								}
 							}
-							/*С2.02ɮʬʥ٥{}ǰϤޤƤ櫓Ǥ̵*/
+							//С2.02ɮʬʥ٥{}ǰϤޤƤ櫓Ǥ̵
 							if(regex_search(source_engine_str,what,m_accv_interface_h2_exp)){
 								accv_interface_h2 = what[0];
 								int length=strlen(accv_interface_h2.c_str());
 								accv_interface_h2=accv_interface_h2.replace(length -2,2,blank_str);
 								//os_policy << accv_interface_h2 << endl;
-								//os_policy << "interface<" <<objclass_interface_h2 << ":" << accv_interface_h2 << ">" << endl;
+								//os_policy << "interface2<" <<objclass_interface_h2 << ":" << accv_interface_h2 << ">" << endl;
 								pattern_matched_access_vector.insert(pair<string, string>(objclass_interface_h2,accv_interface_h2));
 							}
 						}
 					}
 				}
 				is.close();
+
 				/*class νϡ٥ޤȤ뤿˽򤷤ƤФ*/
 				/*̤Ƥtmp_strǡpattern_not_matched_access_vectorȤmultimap򸡺*/
 				/*tmp_strmultimap裲°äС٥*/
@@ -914,7 +954,7 @@ void segatex::segatex_show_interface()
 				p_tmp_objclass_end=unique(v_tmp_objclass.begin(),v_tmp_objclass.end());
 
 				os_policy << "####################################################" << endl;
-				os_policy << "##### This file was generated by segatex2.02" << endl;
+				os_policy << "##### This file was generated by segatex2.03" << endl;
 				os_policy << "####################################################" << endl;
 				os_policy << "#### $make -f /usr/share/selinux/devel/Makefile" << endl;
 				os_policy << "#### will generate module in this directory." << endl;
@@ -935,8 +975,15 @@ void segatex::segatex_show_interface()
 						os_policy << "	class " << p_pattern_not_matched_access_vector->first << " { " ;
 						do{
 							if(p_pattern_not_matched_access_vector->first == p_pattern_not_matched_objclass_pre){
-								//os_policy << p_pattern_not_matched_access_vector->second << " ";
-								v_accv.push_back(p_pattern_not_matched_access_vector->second.c_str());
+								/*Τʤ褦*/
+								cmatch what;
+								regex tmp_re3("(.*)\\$(.*)");
+								if(regex_search(p_pattern_not_matched_access_vector->second.c_str(),what,tmp_re3)){
+									/*⤷ʤ*/
+								}else{
+									//os_policy << p_pattern_not_matched_access_vector->second << " ";
+									v_accv.push_back(p_pattern_not_matched_access_vector->second.c_str());
+								}
 							}
 							p_pattern_not_matched_objclass_pre = p_pattern_not_matched_access_vector->first;
 							p_pattern_not_matched_access_vector++;
@@ -947,7 +994,7 @@ void segatex::segatex_show_interface()
 							string accv_str= *p_accv;
 							os_policy << accv_str << " ";
 						}
-						os_policy << " };" << endl;
+						os_policy << "};" << endl;
 						v_accv.clear();
 					}
 				}
@@ -958,7 +1005,7 @@ void segatex::segatex_show_interface()
 				int v_matched_tmp_domain_size=v_matched_tmp_domain.size();
 				for(int i=0;i < v_matched_tmp_domain_size;i++){
 					v_tmp_domain.push_back(v_matched_tmp_domain[i].c_str());
-					//string test = v_matched_tmp_domain[i];
+					string test = v_matched_tmp_domain[i];
 					//os_policy << test << endl;
 				}
 				sort(v_tmp_domain.begin(),v_tmp_domain.end());
@@ -974,7 +1021,7 @@ void segatex::segatex_show_interface()
 				const char* m_acc_comp = "\\{(.*)\\}";
 				regex m_snmfp_exp(m_snmfp);
 				regex m_acc_comp_exp(m_acc_comp);
-				/*read the allow sentence and divide*/
+				//read the sentence and devide
 				for(p2_v=v2.begin();p2_v < p2_v_end; p2_v++){
 					string source_not_match_final_pre = *p2_v;
 					const char* m_source_not_match_final_pre = source_not_match_final_pre.c_str();
@@ -992,7 +1039,7 @@ void segatex::segatex_show_interface()
 						allow_last=allow_last.replace(0,2,blank_str);
 						//os_policy << allow_last << endl;
 					}
-						/*ޥޥåפѤǤ*/
+						//ޥޥåפѤǤ
 						pattern_allow_not_matched_echo.insert(pair<string, string>(allow_first,allow_last));
 					}
 				}
@@ -1007,12 +1054,12 @@ void segatex::segatex_show_interface()
 					string tmp_str= *p_allow_first;
 					p_pattern_allow_not_matched_echo=pattern_allow_not_matched_echo.find(tmp_str);
 					if(p_pattern_allow_not_matched_echo != pattern_allow_not_matched_echo.end()){
-						/*ո©ɡޤ*/
+						//ո©ɡޤ
 						os_policy << p_pattern_allow_not_matched_echo->first << " { " ;
 						if(p_pattern_allow_not_matched_echo != pattern_allow_not_matched_echo.begin()){
 							os_policy <<  p_pattern_allow_not_matched_echo->second.c_str() << " ";
 						}
-						/*פƤС٥*/
+						//פƤС٥
 						do{
 							if(p_pattern_allow_not_matched_echo->first == p_allow_first_str){
 								v_allow_last.push_back(p_pattern_allow_not_matched_echo->second.c_str());
@@ -1026,7 +1073,7 @@ void segatex::segatex_show_interface()
 							string allow_last_str= *p_allow_last;
 							os_policy << allow_last_str << " ";
 						}
-						os_policy << " };" << endl;
+						os_policy << "};" << endl;
 						v_allow_last.clear();
 					}
 				}
@@ -1037,7 +1084,6 @@ void segatex::segatex_show_interface()
 					string domain_interface_echo_final = *p_domain_interface;	
 					os_policy << domain_interface_echo_final << endl;
 				}
-
 				QFile file( filename_policy); // Read the text from a file
 				if ( file.open( IO_ReadOnly ) ) {
 					QTextStream stream( &file );
